--[[
                                G A D G E T S
      -----------------------------------------------------------------
                            TroubleMagnet@gmail.com
                           TroubleMagnet: Rift Forums 
      -----------------------------------------------------------------
      Gadgets Framework   : v0.3.88
      -----------------------------------------------------------------     
--]]

local toc, data = ...
local AddonId = toc.identifier
local TXT = Library.Translate


-- EnergyMeter provides a simple bar for the player's energy
-- Only useful for mages, and it only exists because I didn't want to add a energy bar to the standard frame

local function Create(configuration)

	local energyMeter = WT.UnitFrame:Create("player")
	energyMeter:SetWidth(170)
	energyMeter:SetHeight(30)
	energyMeter:SetBackgroundColor(0,0,0,0.4)

	energyMeter.mediaTex = Library.Media.GetTexture(configuration.texture)

	energyMeter:CreateElement(
	{
		-- Generic Element Configuration
		id="barResource", type="Bar", parent="frame", layer=10,
		attach = {
			{ point="TOPLEFT", element="frame", targetPoint="TOPLEFT", offsetX=1, offsetY=1 },
			{ point="BOTTOMRIGHT", element="frame", targetPoint="BOTTOMRIGHT", offsetX=-1, offsetY=-1 },
		},
		binding="resourcePercent",
--		colorBinding=configuration.customColor,
		colorBinding="resourceColor",
--		color={r=0,g=0.8,b=0.8,a=0.8},
--		texAddon="wtLibUnitFrame",
--		texFile="img/Glaze2.png",
		media=configuration.texture,
		backgroundColor={r=0, g=0, b=0, a=0.4}
	});
	energyMeter:CreateElement(
	{
		-- Generic Element Configuration
		id="energyLabel", type="Label", parent="frame", layer=20,
		attach = {{ point="CENTER", element="barResource", targetPoint="CENTER", offsetX=0, offsetY=0 }},
		text="{resource}/{resourceMax}", fontSize=10,
	});

	return energyMeter, { resizable = { 140, 12, 300, 50 } }
end


local dialog = false

local function ConfigDialog(container)	
	local lMedia = Library.Media.FindMedia("bar")
	local listMedia = {}
	for mediaId, media in pairs(lMedia) do
		table.insert(listMedia, { ["text"]=mediaId, ["value"]=mediaId })
	end
	dialog = WT.Dialog(container)
		:Label("The Energy Meter displays the current energy/power/mana. ")
		:TexSelect("texture", TXT.Texture, "octanusEnergy", "bar")
--		:Checkbox("enCustomColor", "Custom color enabled", false)
--		:ColorPicker("customColor", "Custom color", {r=1, g=0, b=0, a=0.4})
end

local function GetConfiguration()
	return dialog:GetValues()
end

local function SetConfiguration(config)
	dialog:SetValues(config)
end

local function Reconfigure(config)

	assert(config.id, "No id provided in reconfiguration details")
	
	local gadgetConfig = wtxGadgets[config.id]
	local gadget = WT.Gadgets[config.id]
	
	assert(gadget, "Gadget id does not exist in WT.Gadgets")
	assert(gadgetConfig, "Gadget id does not exist in wtxGadgets")
	assert(gadgetConfig.type == "EnergyBar", "Reconfigure Gadget is not a castbar")
	
	-- Detect changes to config and apply them to the gadget
	
	local requireRecreate = false
	
	if gadgetConfig.texture ~= config.texture then
		gadgetConfig.texture = config.texture
		gadget.mediaTex = Library.Media.GetTexture(config.texture)
	end

	if requireRecreate then
		WT.Gadget.Delete(gadgetConfig.id)
		WT.Gadget.Create(gadgetConfig)
	end		
	
end

WT.Gadget.RegisterFactory("EnergyMeter",
	{
		name="Energy Meter",
		description="Displays current energy/mana",
		author="TroubleMagnet",
		version="1.1.0",
		iconTexAddon=AddonId,
		iconTexFile="img/wtFPS.png",
		["Create"] = Create,
		["ConfigDialog"] = ConfigDialog,
		["GetConfiguration"] = GetConfiguration, 
		["SetConfiguration"] = SetConfiguration, 
	})

